<?php
/**
 * ImageType
 * 图片类型
 * $Id: ImageType.inc 90242 2015-09-29 11:27:35Z wulk $
 * @author iimuro
 * @access public
 * @package cn.compass.entity.definition
 */
 
class ImageType{
	
	
	public $id;
	
	/**
	 * 定義名
	 */
	public $name;
	
	/**
	 * 表示用名前
	 */
	public $title;
	
	/**
	 * 種類。IMAGE, TEXT, BINARYのいずれか。
	 */
	public $type;
	
	/**
	 * ヘッダー文字列
	 */
	public $header;
	
	/**
	 * ヘッダーの種類は
	 * 種類が複数ある場合もある。その場合、ここにその候補を書く。
	 */
	public $alt_header_list;
	
	
	/**
	 * 拡張子。.はつけない。
	 * 例:jpg
	 */
	public $extention;
	
	/**
	 * Ezweb用メディア指定用コード
	 */
	public $disposition;
	
	/**
	 * 拡張子の複数種類がある場合の候補。
	 */
	public $alt_extention_list;
	
	function __construct($record) {
		
		$this->id = $record["id"];
		$this->name = $record["name"];
		$this->title = $record["title"];
		$this->type = $record["type"];
		$this->header = $record["header"];
		$this->alt_header_list = $record["alt_header_list"];
		$this->extention = $record["extention"];
		$this->alt_extention_list = $record["alt_extention_list"];
		$this->disposition = $record["disposition"];
		
	}
	
	
	/**
	 * このクラスのインスタンスのリストを返します。
	 * @return array ImageType一覧
	 */
	public static function getList() {
		static $result;
			
		if ((!is_array($result)) || (count($result) < 1)) {
			
			$data = array();
			$tmp = array("id"=>1, "name"=>"GIF", "type"=>"IMAGE", "title"=>"GIF",
						"header"=>"image/gif", "alt_header_list"=>array(),
						"extention"=>"gif", "alt_extention_list"=>array(), "disposition"=>"devgi0z");
			array_push($data, $tmp);
			$tmp = array("id"=>2, "name"=>"PNG", "type"=>"IMAGE", "title"=>"PNG",
						"header"=>"image/png", "alt_header_list"=>array("image/x-png"),
						"extention"=>"png", "alt_extention_list"=>array(), "disposition"=>"dev8aww");
			array_push($data, $tmp);
			$tmp = array("id"=>3, "name"=>"JPG", "type"=>"IMAGE", "title"=>"JPG",
						"header"=>"image/jpeg", "alt_header_list"=>array("image/jpeg", "image/x-jpg", "image/pjpeg"),
						"extention"=>"jpg", "alt_extention_list"=>array("jpeg", "jpe"), "disposition"=>"devjaww");
			array_push($data, $tmp);
			$tmp = array("id"=>4, "name"=>"BMP", "type"=>"IMAGE", "title"=>"BMP",
						"header"=>"image/bmp", "alt_header_list"=>array(),
						"extention"=>"bmp", "alt_extention_list"=>array(), "disposition"=>"dev2abm");
			array_push($data, $tmp);
			$tmp = array("id"=>5, "name"=>"SWF", "type"=>"IMAGE", "title"=>"Flash",
						"header"=>"application/x-shockwave-flash", "alt_header_list"=>array(),
						"extention"=>"swf", "alt_extention_list"=>array(), "disposition"=>"devfl7z");
			array_push($data, $tmp);
						$tmp = array("id"=>6, "name"=>"SVG", "type"=>"IMAGE", "title"=>"SVG",
						"header"=>"image/svg+xml", "alt_header_list"=>array(),
						"extention"=>"svg", "alt_extention_list"=>array(), "disposition"=>"dev0001");
			array_push($data, $tmp);
			
		
			$result = array();
			foreach ($data as $row) {
				$tmp2 = new ImageType($row);
				array_push($result, $tmp2);
			}
		}
		return $result;
	}
	
	/**
	 * IDから対応するインスタンスを返します。
	 * @return ImageType 対応するインスタンス。ない場合null。
	 */
	public static function getById($id) {
		$list = ImageType::getList();
		foreach ($list as $tmp) {
			if ($tmp->id == $id) {
				return $tmp;
			}
		}
		return null;
	}
	
	/**
	 * 名称を指定してインスタンスを取得します。
	 * @return ImageType 対応するインスタンス。ない場合null。
	 */
	public static function getByName($name) {
		$list = ImageType::getList();
		foreach ($list as $tmp) {
			if ($tmp->name == strtoupper($name)) {
				return $tmp;
			}
		}
		return null;
	}
	
	
	/**
	 * タイプを指定して種類を取得します。
	 */
	public static function getListByType($type) {
		// TODO 実装
		
		
	}
	
	/**
	 * ヘッダーのcontent-type文字列からインスタンスを取得します。
	 * $headerまたは$alt_header_listに一致するものが合った場合。
	 * 無い場合、null。
	 */
	public static function getByHeader($header_string) {
		
		$list = ImageType::getList();

		$result = null;
		foreach ($list as $type) {
			if ((trim($header_string) == $type->header)
				|| (@in_array(trim($header_string), $type->alt_header_list))) {
				
				$result = $type;
				
				break;
			}
			
		}
		
		return $result;
	}
	
	/**
	 * ファイルの拡張子からインスタンスを取得します。
	 * $extentionまたは$alt_extentionlistの中に一致するものがあった場合。無い場合、null。
	 */
	public static function getByExtention($extention_string) {
		$list = ImageType::getList();
		
		$result = null;
		foreach ($list as $type) {
			
			if ((trim($extention_string) == $type->extention)
				|| (in_array(trim($extention_string), $type->alt_extention_list))) {
				
				$result = $type;
				
				break;
			}
			
		}
		
		return $result;
	}
	
	
}

?>